@@ -5,7 +5,7 @@ use crate::wasmbus_model::Wasmbus;
 use crate::{
     config::LanguageConfig,
     error::{print_warning, Error, Result},
-    gen::CodeGen,
+    gen::{CodeGen, SourceFormatter},
     model::{
         codegen_rust_trait, get_operation, get_trait, has_default, is_opt_namespace,
         serialization_trait, value_to_json, wasmcloud_model_namespace, CommentKind, PackageName,
@@ -13,7 +13,7 @@ use crate::{
     render::Renderer,
     wasmbus_model::{CodegenRust, Serialization},
     writer::Writer,
-    BytesMut, JsonValue, ParamMap, TomlValue,
+    BytesMut, JsonValue, ParamMap,
 };
 use atelier_core::model::shapes::ShapeKind;
 use atelier_core::{
@@ -34,12 +34,7 @@ use atelier_core::{
         TRAIT_TRAIT, TRAIT_UNSTABLE,
     },
 };
-use std::{
-    collections::{BTreeMap, HashMap},
-    path::{Path, PathBuf},
-    str::FromStr,
-    string::ToString,
-};
+use std::{collections::HashMap, path::Path, str::FromStr, string::ToString};
 
 const WASMBUS_RPC_CRATE: &str = "wasmbus_rpc";
 
@@ -157,29 +152,8 @@ impl<'model> CodeGen for RustCodeGen<'model> {
         Ok(())
     }
 
-    /// After code generation has completed for all files, this method is called once per output language
-    /// to allow code formatters to run. The `files` parameter contains a list of all files written or updated.
-    fn format(
-        &mut self,
-        files: Vec<PathBuf>,
-        lc_params: &BTreeMap<String, TomlValue>,
-    ) -> Result<()> {
-        // if we just created an interface project, don't run rustfmt yet
-        // because we haven't generated the other rust file yet, so rustfmt will fail.
-        if !lc_params.contains_key("create_interface") {
-            // make a list of all output files with ".rs" extension so we can fix formatting with rustfmt
-            // minor nit: we don't check the _config-only flag so there could be some false positives here, but rustfmt is safe to use anyway
-            let rust_sources = files
-                .into_iter()
-                .filter(is_rust_source)
-                .collect::<Vec<PathBuf>>();
-
-            if !rust_sources.is_empty() {
-                let formatter = crate::rustfmt::RustFmtCommand::default();
-                formatter.execute(rust_sources)?;
-            }
-        }
-        Ok(())
+    fn source_formatter(&self) -> Result<Box<dyn SourceFormatter>> {
+        Ok(Box::new(crate::format::RustSourceFormatter::default()))
     }
 
     /// Perform any initialization required prior to code generation for a file
@@ -361,7 +335,7 @@ impl<'model> CodeGen for RustCodeGen<'model> {
 
 /// returns true if the file path ends in ".rs"
 #[allow(clippy::ptr_arg)]
-fn is_rust_source(path: &PathBuf) -> bool {
+pub(crate) fn is_rust_source(path: &Path) -> bool {
     match path.extension() {
         Some(s) => s.to_string_lossy().as_ref() == "rs",
         _ => false,
@@ -487,7 +461,7 @@ impl<'model> RustCodeGen<'model> {
                             w.write(&self.to_type_name(&id.shape_name().to_string()));
                         }
                         None => {
-                            return Err(Error::Model(format!("underined create for namespace {} for symbol {}. Make sure codegen.toml includes all dependent namespaces",
+                            return Err(Error::Model(format!("undefined create for namespace {} for symbol {}. Make sure codegen.toml includes all dependent namespaces",
                                     &id.namespace(), &id)));
                         }
                     }
@@ -608,7 +582,7 @@ impl<'model> RustCodeGen<'model> {
             if let Some(cg) = get_trait::<CodegenRust>(traits, codegen_rust_trait())? {
                 cg.derive_default
             } else {
-                false
+                true
             };
         w.write(b"#[derive(");
         if derive_default {
@@ -729,7 +703,6 @@ impl<'model> RustCodeGen<'model> {
         w.write(b"#[async_trait]\npub trait ");
         self.write_ident(&mut w, service_id);
         w.write(b"{\n");
-        //HERE
         for operation in service.operations() {
             // if operation is not declared in this namespace, don't define it here
             if let Some(ref ns) = self.namespace {
@@ -739,7 +712,7 @@ impl<'model> RustCodeGen<'model> {
             }
             let (op, op_traits) = get_operation(model, operation, service_id)?;
 
-            // TODO: re-think what to do if operation is in another namspace and self.namespace is None
+            // TODO: re-think what to do if operation is in another namespace and self.namespace is None
             let method_id = operation.shape_name();
             self.write_method_signature(&mut w, method_id, op_traits, op)?;
             w.write(b";\n");
@@ -826,7 +799,7 @@ impl<'model> RustCodeGen<'model> {
             async fn dispatch(
                 &self,
                 ctx: &context::Context<'_>,
-                message: &Message<'_> ) -> Result< Message<'static>, RpcError> {
+                message: &Message<'_> ) -> Result< Message<'_>, RpcError> {
                 match message.method {
         "#,
         );
